import QtQuick 2.0
import Sailfish.Silica 1.0
import com.jolla.settings 1.0
import com.jolla.settings.system 1.0
import org.nemomobile.systemsettings 1.0
import org.nemomobile.configuration 1.0

Page {
    id: root
	
    ConfigurationGroup {
        id: topMenuSettings
        path: "/desktop/lipstick-jolla-home/topMenuSettings"
        property int ambience_count: 4
		property bool restart_homescreen: true
		property int shortcuts_count: 4
		property bool profile_button: false
        property bool swipe_to_lock: false
		property int threshold: 50
		property bool old_slider: true
		property bool text: false
		property string ownText: ownText.text
		property int y: 480
    }

    SilicaFlickable {
        anchors.fill: parent
        contentHeight: column.height + Theme.paddingLarge

        VerticalScrollDecorator {}

        Column {
            id: column
            width: parent.width
			
            PageHeader {
                title: qsTr("Power menu")
            }		
			
			TextSwitch {
	            width: parent.width
	            text: qsTr("Restart homescreen button")
	            checked: topMenuSettings.restart_homescreen
	            onClicked: topMenuSettings.restart_homescreen = checked
	        }
			
            TextSwitch {
                //% "Show reboot action on top menu"
                text: qsTrId("settings_developermode-bu-show_reboot_action")

                automaticCheck: false
                checked: rebootActionConfig.value
                onClicked: rebootActionConfig.value = !rebootActionConfig.value

                ConfigurationValue {
                    id: rebootActionConfig

                    key: "/desktop/jolla/reboot_action_enabled"
                    defaultValue: false
                }
            }	
			
			TextSwitch {
	            width: parent.width
	            text: qsTr("Profile button in lock menu")
                checked: topMenuSettings.profile_button
	            onClicked: topMenuSettings.profile_button = checked
	        }
				
			TextSwitch {
	            width: parent.width
	            text: qsTr("Swipe to lock")
			    description: qsTr("A top edge swipe will permit to lock the screen")
	            checked: topMenuSettings.swipe_to_lock
	            onClicked: topMenuSettings.swipe_to_lock = checked
	        }	
			
            Slider {
                width: parent.width
                visible: topMenuSettings.swipe_to_lock

                label: qsTr("Lock threshold")
                maximumValue: 90
                minimumValue: 20
                stepSize: 1
                value: topMenuSettings.threshold
                valueText: value + "%"

                onPressAndHold: cancel()
                onValueChanged: topMenuSettings.threshold = Math.round(value)
            }
            PageHeader {
                //% "Top menu"
                title: qsTrId("settings_topmenu-he-topmenu")
            }
			
			TextSwitch {
	            width: parent.width
	            text: qsTr("Old slider style")
	            checked: topMenuSettings.old_slider
	            onClicked: topMenuSettings.old_slider = checked
	        }
						
			Slider {
			    width: parent.width
				visible: topMenuAmbiencesEnabled.value
                label: qsTr("Ambience count")
                maximumValue: 8
                minimumValue: 4
                stepSize: 1
                value: topMenuSettings.ambience_count
                valueText: value

                onValueChanged: topMenuSettings.ambience_count = value
                onPressAndHold: cancel()
			}
			
			Slider {
			    width: parent.width
                label: qsTr("Number of elements in a row")
                maximumValue: 6
                minimumValue: 4
                stepSize: 1
                value: topMenuSettings.shortcuts_count
                valueText: value

                onValueChanged: topMenuSettings.shortcuts_count = value
                onPressAndHold: cancel()
			}
			
            PageHeader {
                title: qsTr("Eventsview")
            }
			
			TextSwitch {
	            width: parent.width
	            text: qsTr("Custom 'No notifications' text")
	            checked: topMenuSettings.text
	            onClicked: topMenuSettings.text = checked
            }			
				
            TextArea {
                id: ownText
				visible: topMenuSettings.text
                width: parent.width
                placeholderText: qsTr("Type your text here")
                label: qsTr("Enter your custom text")
                text: topMenuSettings.ownText
                focusOutBehavior: topMenuSettings.ownText = text	
            }
			
			Item {
			    enabled: topMenuSettings.text
			    width: 1
				height: Theme.paddingLarge*4
			}
			
			Slider {
				width: parent.width
				visible: topMenuSettings.text
				label: qsTr("Vertical text position")
				maximumValue: 2000
				minimumValue: 0
				stepSize: 10
				value: topMenuSettings.y
				valueText: value + " " + qsTr("px")

				onValueChanged: topMenuSettings.y = Math.round(value)
				onPressAndHold: cancel()
		    }
			
            PageHeader {
                title: qsTr("About")
            }

            Label {
                width: parent.width
                wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("Created by Ancelad in 0x7E2. Contains eugenio's swipe-to-lock patch code.")
            }
			
			Item {
			    
			    width: 1
				height: Theme.paddingLarge
			}
			
		    Label {
                text: qsTr("Donations are welcome :)")
                width: parent.width
				wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
            }
			
			Item {
			    
			    width: 1
				height: Theme.paddingLarge
			}
			
            Button {
                text: qsTr("Donate")
                width: text.width
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    Qt.openUrlExternally("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=E33PBZ79WTQJY")
                }
            }			
        }
    }
}
